@@ -33,10 +33,12 @@ AIC.bn = function(object, data, ..., k = 1) {
   type = data.type(data)
 
   # parameter sanitization done in the score() function.
-  if (type %in% c("factor", "ordered", "mixed-do"))
+  if (type %in% discrete.data.types)
     score(object, data = data, type = "aic", k = k, ...)
-  else
+  else if (type == "continuous")
     score(object, data = data, type = "aic-g", k = k, ...)
+  else if (type == "mixed-cg")
+    score(object, data = data, type = "aic-cg", k = k, ...)
 
 }#AIC.BN
 
@@ -47,10 +49,12 @@ BIC.bn = function(object, data, ...) {
   type = data.type(data)
 
   # parameter sanitization done in the score() function.
-  if (type %in% c("factor", "ordered", "mixed-do"))
+  if (type %in% discrete.data.types)
     score(object, data = data, type = "bic", ...)
-  else
+  else if (type == "continuous")
     score(object, data = data, type = "bic-g", ...)
+  else if (type == "mixed-cg")
+    score(object, data = data, type = "bic-cg", ...)
 
 }#BIC.BN
 
@@ -61,10 +65,12 @@ logLik.bn = function(object, data, ...) {
   type = data.type(data)
 
   # parameter sanitization done in the score() function.
-  if (type %in% c("factor", "ordered", "mixed-do"))
+  if (type %in% discrete.data.types)
     score(x = object, data = data, type = "loglik", ...)
-  else
+  else if (type == "continuous")
     score(x = object, data = data, type = "loglik-g", ...)
+  else if (type == "mixed-cg")
+    score(x = object, data = data, type = "loglik-cg", ...)
 
 }#LOGLIK.BN
 
