@@ -1,6 +1,6 @@
 
 # Pena's irrelevant nodes feature selection.
-pena.backend  = function(target, context, data, test, alpha, debug = TRUE) {
+pena.backend  = function(target, context, data, test, alpha, B, debug = TRUE) {
 
   to.test = relevant = target
   nodes = setdiff(names(data), context)
@@ -30,8 +30,8 @@ pena.backend  = function(target, context, data, test, alpha, debug = TRUE) {
       }#THEN
 
       # compute the marginal associations.
-      association = sapply(setdiff(nodes, relevant), conditional.test, y = node,
-                    sx = context, data = data, test = test)
+      association = indep.test(setdiff(nodes, relevant), y = node, sx = context,
+                      data = data, test = test, alpha = alpha, B = B)
 
      if (debug) {
 
