@@ -1,4 +1,4 @@
-#include "common.h"
+#include "include/rcore.h"
 
 SEXP BN_ModelstringSymbol;
 SEXP BN_NodesSymbol;
